@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Shipwright::Util;
 
-use base qw/App::CLI::Command Class::Accessor::Fast Shipwright::Script/;
+use base qw/App::CLI::Command Shipwright::Base Shipwright::Script/;
 __PACKAGE__->mk_accessors(qw/with_latest_version only_update/);
 
 use Shipwright;
